import Aliaser from './Aliaser';
import Binder from './Binder';
import Builder from './Builder';
import Callable from './Callable';
import ContainerContract from '../Contracts/Container/Container';
import ContextualBindingBuilder from './ContextualBindingBuilder';
import ContextualBinder from './ContextualBinder';
import Extender from './Extender';
import InstanceSharer from './InstanceSharer';
import MethodBinder from './MethodBinder';
import Resolver from './Resolver';
import Tagger from './Tagger';
import { Binding, Identifier, Instantiable } from '../types/container';
declare class Container implements ContainerContract {
    protected static _instance?: Container;
    protected _contextualBinder: ContextualBinder;
    protected _aliaser: Aliaser;
    protected _instanceSharer: InstanceSharer;
    protected _builder: Builder;
    protected _methodBinder: MethodBinder;
    protected _binder: Binder;
    protected _resolver: Resolver;
    protected _extender: Extender;
    protected _tagger: Tagger;
    constructor();
    static getInstance(): Container;
    static setInstance(container?: Container): Container | undefined;
    when<T>(concrete: Instantiable<T>[] | Instantiable<T>): ContextualBindingBuilder;
    bound<T>(abstract: Identifier<T>): boolean;
    has<T>(id: Identifier<T>): boolean;
    resolved<T>(abstract: Identifier<T>): boolean;
    isShared<T>(abstract: Identifier<T>): boolean;
    isAlias<T>(name: Identifier<T>): boolean;
    bind<U, V>(abstract: Identifier<U>, concrete?: Instantiable<V> | Function, shared?: boolean): void;
    unbind<T>(abstract: Identifier<T>): void;
    hasMethodBinding(method: string): boolean;
    bindMethod<T>(method: [Instantiable<T>, string] | string, callback: Function): void;
    callMethodBinding(method: string, instance: any): any;
    bindIf<U, V>(abstract: Identifier<U>, concrete?: Instantiable<V> | Function, shared?: boolean): void;
    singleton<U, V>(abstract: Identifier<U>, concrete?: Instantiable<V> | Function): void;
    extend<T>(abstract: Identifier<T>, closure: Function): void;
    instance<U, V>(abstract: Identifier<U>, instance: V): V;
    tag<T>(abstracts: Identifier<T>[] | Identifier<T>, tags: string[]): void;
    tagged(tag: string): any[] | IterableIterator<any>;
    alias<U, V>(abstract: Identifier<U>, alias: Identifier<V>): void;
    rebinding<T>(abstract: Identifier<T>, callback: Function): unknown | undefined;
    refresh<T>(abstract: Identifier<T>, target: object, method: string): unknown;
    wrap<T>(callback: Callable<T>, parameters?: any[] | object): Function;
    call<T>(callback: Callable<T>, parameters?: any[] | object, defaultMethod?: string): any;
    factory<T>(abstract: Identifier<T>): Function;
    make<T>(abstract: Identifier<T>, parameters?: any[] | object): any;
    resolve<T>(abstract: Identifier<T>, parameters?: any[] | object, raiseEvents?: boolean): any;
    get<T>(id: Identifier<T>): any;
    set<U, V>(id: Identifier<U>, value: V): void;
    build<T>(concrete: Instantiable<T> | Function): any;
    resolving<T>(abstract: Identifier<T> | Function, callback?: Function): void;
    afterResolving<T>(abstract: Identifier<T> | Function, callback?: Function): void;
    getBindings(): Map<any, Binding>;
    getBinder(): Binder;
    getInstanceSharer(): InstanceSharer;
    getBuilder(): Builder;
    getResolver(): Resolver;
    getAliaser(): Aliaser;
    getContextualBinder(): ContextualBinder;
    getExtender(): Extender;
    getAlias<T>(abstract: Identifier<T>): Identifier<any>;
    forgetExtenders<T>(abstract: Identifier<T>): void;
    forgetInstance<T>(abstract: Identifier<T>): void;
    forgetInstances(): void;
    flush(): void;
    rebound<T>(abstract: Identifier<T>): void;
}
export default Container;
